==> plplot-5.5.2.tbz: share/plplot5.5.2/examples/f77/x10f.f <==
C      $Id: x10f.fm4,v 1.9 2004/01/17 16:41:39 rlaboiss Exp $
C      Demonstration program for PLplot illustrating absolute positioning
C      of graphs on a page
C
C      Copyright (C) 2004  Alan W. Irwin
C
C      This file is part of PLplot.
C
C      PLplot is free software; you can redistribute it and/or modify
C      it under the terms of the GNU General Library Public License as
C      published by the Free Software Foundation; either version 2 of the
C      License, or (at your option) any later version.
C
C      PLplot is distributed in the hope that it will be useful,
C      but WITHOUT ANY WARRANTY; without even the implied warranty of
C      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C      GNU Library General Public License for more details.
C
C      You should have received a copy of the GNU Library General Public
C      License along with PLplot; if not, write to the Free Software
C      Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA

      implicit none
      integer PL_PARSE_FULL
      parameter(PL_PARSE_FULL = 1)
C      Process command-line arguments
      call plparseopts(PL_PARSE_FULL)


      call plinit()

      call pladv(0)
      call plvpor(0.0d0, 1.0d0, 0.0d0, 1.0d0 )
      call plwind(0.0d0, 1.0d0, 0.0d0, 1.0d0 )
      call plbox('bc', 0.0d0, 0, 'bc', 0.0d0, 0 )

      call plsvpa(50.0d0, 150.0d0, 50.0d0,
     &  100.0d0 )
      call plwind(0.0d0, 1.0d0, 0.0d0, 1.0d0 )
      call plbox('bc', 0.0d0, 0, 'bc', 0.0d0, 0 )
      call plptex(0.5d0, 0.5d0, 1.0d0, 0.0d0,
     &  0.5d0, 'BOX at (50,150,50,100)' )

      call plend

      end

==> plplot-5.6.1.tbz: share/plplot5.6.1/examples/f77/x10f.f <==
C      $Id: x10f.fm4,v 1.10 2005/04/27 06:43:54 rlaboiss Exp $
C      Demonstration program for PLplot illustrating absolute positioning
C      of graphs on a page
C
C      Copyright (C) 2004  Alan W. Irwin
C
C      This file is part of PLplot.
C
C      PLplot is free software; you can redistribute it and/or modify
C      it under the terms of the GNU General Library Public License as
C      published by the Free Software Foundation; either version 2 of the
C      License, or (at your option) any later version.
C
C      PLplot is distributed in the hope that it will be useful,
C      but WITHOUT ANY WARRANTY; without even the implied warranty of
C      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C      GNU Library General Public License for more details.
C
C      You should have received a copy of the GNU Library General Public
C      License along with PLplot; if not, write to the Free Software
C      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA

      implicit none
      integer PL_PARSE_FULL
      parameter(PL_PARSE_FULL = 1)
C      Process command-line arguments
      call plparseopts(PL_PARSE_FULL)


      call plinit()

      call pladv(0)
      call plvpor(0.0d0, 1.0d0, 0.0d0, 1.0d0 )
      call plwind(0.0d0, 1.0d0, 0.0d0, 1.0d0 )
      call plbox('bc', 0.0d0, 0, 'bc', 0.0d0, 0 )

      call plsvpa(50.0d0, 150.0d0, 50.0d0,
     &  100.0d0 )
      call plwind(0.0d0, 1.0d0, 0.0d0, 1.0d0 )
      call plbox('bc', 0.0d0, 0, 'bc', 0.0d0, 0 )
      call plptex(0.5d0, 0.5d0, 1.0d0, 0.0d0,
     &  0.5d0, 'BOX at (50,150,50,100)' )

      call plend

      end
